@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 =head1 NAME
 
@@ -18,7 +18,17 @@ CPAN::Testers::WWW::Reports::Mailer - CPAN Testers Reports Mailer
 
 =head1 DESCRIPTION
 
-CPAN Testers daily Summary reports mailer
+The CPAN Testers Reports Mailer takes the preferences set within the CPANPREFS
+database, and uses them to filter out reports that the author does or does not
+wish to be made aware of.
+
+New authors are added to the system as a report for their first reported
+distribution is submitted by a tester. Default settings are applied in the
+first instance, with the author able to update these via the preferences
+website.
+
+Initially only a Daily Summary Report is available, in time a Weekly Summary
+Report and the individual reports will also be available.
 
 =cut
 
@@ -114,6 +124,7 @@ my %phrasebook = (
 sub init_options {
     GetOptions( \%options,
         'config=s',
+        'debug',
         'help|h',
         'version|v'
     );
@@ -128,12 +139,13 @@ sub init_options {
 
     # configure databases
     for my $db (qw(CPANSTATS CPANPREFS)) {
+        die "No configuration for $db database\n"   unless($cfg->SectionExists($db));
         my %opts = map {$_ => $cfg->val($db,$_);} qw(driver database dbfile dbhost dbport dbuser dbpass);
         $options{$db} = CPAN::Testers::Common::DBUtils->new(%opts);
         die "Cannot configure $db database\n" unless($options{$db});
     }
 
-    $config{$_} = $cfg->val('SETTINGS',$_)  for(qw(DEBUG));
+    $config{DEBUG} = $options{debug} || $cfg->val('SETTINGS','DEBUG');
 
     $options{pause} = download_mailrc();
 
@@ -476,7 +488,7 @@ sub write_mail {
     $body =~ s/SUBJECT/$subject/g;
 
     if($config{DEBUG}) {
-        print "$body\n";
+        print "TEST: $parms->{author}\n";
         return;
     }
 
